@@ -1,25 +1,10 @@
-﻿define(['libraryBrowser', 'cardBuilder', 'appSettings', 'components/groupedcards', 'scrollStyles', 'emby-button', 'paper-icon-button-light', 'emby-itemscontainer'], function (LibraryBrowser, cardBuilder, appSettings, groupedcards) {
+﻿define(['libraryBrowser', 'cardBuilder', 'appSettings', 'components/groupedcards', 'dom', 'apphost', 'scrollStyles', 'emby-button', 'paper-icon-button-light', 'emby-itemscontainer'], function (libraryBrowser, cardBuilder, appSettings, groupedcards, dom, appHost) {
 
     function getUserViews(userId) {
 
         return ApiClient.getUserViews({}, userId).then(function (result) {
 
-            var items = result.Items;
-
-            var list = [];
-
-            for (var i = 0, length = items.length; i < length; i++) {
-
-                var view = items[i];
-
-                if (AppInfo.isNativeApp && browserInfo.safari && view.CollectionType == 'livetv') {
-                    continue;
-                }
-
-                list.push(view);
-            }
-
-            return list;
+            return result.Items;
         });
     }
 
@@ -95,7 +80,7 @@
                 cssClass += ' ' + item.CollectionType + 'buttonCard';
             }
 
-            var href = item.url || LibraryBrowser.getHref(item);
+            var href = item.url || libraryBrowser.getHref(item);
             var onclick = item.onclick ? ' onclick="' + item.onclick + '"' : '';
 
             icon = item.icon || icon;
@@ -192,7 +177,7 @@
     function getCard(img, target, shape) {
 
         shape = shape || 'backdropCard';
-        var html = '<div class="card scalableCard ' + shape + '"><div class="cardBox"><div class="cardScalable"><div class="cardPadder cardPadder-backdrop"></div>';
+        var html = '<div class="card scalableCard ' + shape + ' ' + shape + '-scalable"><div class="cardBox"><div class="cardScalable"><div class="cardPadder cardPadder-backdrop"></div>';
 
         if (target) {
             html += '<a class="cardContent" href="' + target + '" target="_blank">';
@@ -347,7 +332,8 @@
                     lazy: true,
                     context: 'home',
                     centerText: true,
-                    overlayPlayButton: true
+                    overlayPlayButton: true,
+                    allowBottomPadding: !enableScrollX()
                 });
                 html += '</div>';
             }
@@ -390,7 +376,8 @@
                     showChildCountIndicator: true,
                     lazy: true,
                     context: 'home',
-                    overlayPlayButton: true
+                    overlayPlayButton: true,
+                    allowBottomPadding: !enableScrollX()
                 });
                 html += '</div>';
             }
@@ -402,7 +389,7 @@
 
     function loadLatestChannelMedia(elem, userId) {
 
-        var screenWidth = window.innerWidth;
+        var screenWidth = dom.getWindowSize().innerWidth;
 
         var options = {
 
@@ -451,28 +438,28 @@
 
             if (items.length) {
 
-                var screenWidth = window.innerWidth;
-
                 html += '<div>';
                 html += '<h1 class="listHeader">' + Globalize.translate('HeaderMyMedia') + '</h1>';
 
                 html += '</div>';
 
-                var scrollX = enableScrollX() && browserInfo.safari && screenWidth > 800;
+                var scrollX = enableScrollX() && dom.getWindowSize().innerWidth >= 600;
 
                 if (scrollX) {
                     html += '<div is="emby-itemscontainer" class="hiddenScrollX itemsContainer">';
                 } else {
                     html += '<div is="emby-itemscontainer" class="itemsContainer vertical-wrap">';
                 }
+
                 html += cardBuilder.getCardsHtml({
                     items: items,
                     shape: scrollX ? 'overflowBackdrop' : shape,
                     showTitle: showTitles,
                     centerText: true,
+                    overlayText: false,
                     lazy: true,
-                    autoThumb: true,
-                    transition: false
+                    transition: false,
+                    allowBottomPadding: !enableScrollX()
                 });
                 html += '</div>';
             }
@@ -495,7 +482,7 @@
 
     function loadResume(elem, userId) {
 
-        var screenWidth = window.innerWidth;
+        var screenWidth = dom.getWindowSize().innerWidth;
 
         var options = {
 
@@ -535,7 +522,8 @@
                     showDetailsMenu: true,
                     overlayPlayButton: true,
                     context: 'home',
-                    centerText: true
+                    centerText: true,
+                    allowBottomPadding: !enableScrollX()
                 });
                 html += '</div>';
             }
@@ -568,6 +556,9 @@
                 } else {
                     html += '<div is="emby-itemscontainer" class="itemsContainer vertical-wrap">';
                 }
+
+                var supportsImageAnalysis = appHost.supports('imageanalysis');
+
                 html += cardBuilder.getCardsHtml({
                     items: result.Items,
                     preferThumb: true,
@@ -578,7 +569,10 @@
                     lazy: true,
                     overlayPlayButton: true,
                     context: 'home',
-                    centerText: true
+                    centerText: true,
+                    allowBottomPadding: !enableScrollX(),
+                    cardLayout: supportsImageAnalysis,
+                    vibrant: supportsImageAnalysis
                 });
                 html += '</div>';
             }
@@ -621,7 +615,7 @@
 
     function loadLatestChannelItemsFromChannel(page, channel, index) {
 
-        var screenWidth = window.innerWidth;
+        var screenWidth = dom.getWindowSize().innerWidth;
 
         var options = {
 
@@ -667,7 +661,7 @@
         });
     }
 
-    function loadLatestLiveTvRecordings(elem, userId, index) {
+    function loadLatestLiveTvRecordings(elem, userId) {
 
         return ApiClient.getLiveTvRecordings({
 
@@ -683,10 +677,8 @@
 
             if (result.Items.length) {
 
-                var cssClass = index !== 0 ? 'listHeader' : 'listHeader';
-
                 html += '<div>';
-                html += '<h1 style="display:inline-block; vertical-align:middle;" class="' + cssClass + '">' + Globalize.translate('HeaderLatestTvRecordings') + '</h1>';
+                html += '<h1 style="display:inline-block; vertical-align:middle;" class="listHeader">' + Globalize.translate('HeaderLatestTvRecordings') + '</h1>';
                 html += '<a href="livetv.html?tab=3" onclick="LibraryBrowser.showTab(\'livetv.html\',3);" class="clearLink" style="margin-left:2em;"><button is="emby-button" type="button" class="raised more mini"><span>' + Globalize.translate('ButtonMore') + '</span></button></a>';
                 html += '</div>';
             }
@@ -696,6 +688,9 @@
             } else {
                 html += '<div is="emby-itemscontainer" class="itemsContainer vertical-wrap">';
             }
+
+            var supportsImageAnalysis = appHost.supports('imageanalysis');
+
             html += cardBuilder.getCardsHtml({
                 items: result.Items,
                 shape: enableScrollX() ? 'autooverflow' : 'auto',
@@ -704,8 +699,14 @@
                 coverImage: true,
                 lazy: true,
                 showDetailsMenu: true,
-                centerText: true,
-                overlayPlayButton: true
+                centerText: !supportsImageAnalysis,
+                overlayText: false,
+                overlayPlayButton: true,
+                allowBottomPadding: !enableScrollX(),
+                preferThumb: true,
+                cardLayout: supportsImageAnalysis,
+                vibrant: supportsImageAnalysis
+
             });
             html += '</div>';
 
